aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAnders Kalør <anders@kaloer.com>2019-08-10 21:49:55 +0200
committermormj <34754695+mormj@users.noreply.github.com>2019-12-04 12:10:33 -0500
commitb6580394aea850f5176469d854696e4f55e11918 (patch)
tree832f3aed71d1c2cc2ba83e56894470612867019d
parentmodtool: use Boost UTF for 3.8 OOT blocks (diff)
downloadgnuradio-b6580394aea850f5176469d854696e4f55e11918.tar.xz
gnuradio-b6580394aea850f5176469d854696e4f55e11918.zip
Add gr::modname namespace to Boost UTF template
-rw-r--r--gr-utils/python/modtool/templates/templates.py13
1 files changed, 9 insertions, 4 deletions
diff --git a/gr-utils/python/modtool/templates/templates.py b/gr-utils/python/modtool/templates/templates.py
index e6c1197dd..f811dc610 100644
--- a/gr-utils/python/modtool/templates/templates.py
+++ b/gr-utils/python/modtool/templates/templates.py
@@ -453,11 +453,16 @@ ${str_to_fancyc_comment(license)}
#include <gnuradio/attributes.h>
#include <boost/test/unit_test.hpp>
-BOOST_AUTO_TEST_CASE(test_${blockname}_t1)
-{
- // Put test here
-}
+namespace gr {
+ namespace ${modname} {
+
+ BOOST_AUTO_TEST_CASE(test_${blockname}_t1)
+ {
+ // Put test here
+ }
+ } /* namespace ${modname} */
+} /* namespace gr */
'''
# C++ file for QA